MODULE constants
!
!**********************************************************************************
!*  CONSTANTS                                                                     *
!**********************************************************************************
!* This module contains mathematical and physical constants                       *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!* pierre.hirel@izbs.uni-karlsruhe.de                                             *
!* Last modification: P. Hirel - 30 April 2010                                    *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater:          *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!**********************************************************************************
!
!
! MATHS
!
REAL*8,PARAMETER:: zero  = 0.d0
REAL*8,PARAMETER:: sqrt2 = DSQRT(2.d0)
REAL*8,PARAMETER:: pi    = 4.d0*DATAN(1.d0)
!
!
!
! PHYSICS-MATERIALS
!
!General
REAL*8,PARAMETER:: kB       = 1.3806504d-23               !Boltzmann's constant (J/K)
REAL*8,PARAMETER:: h_planck = 6.6260693d-34               !Plank's constant (kg.m²/s)
REAL*8,PARAMETER:: h_bar    = h_planck/(2.d0*pi)          !Reduced Plank's constant (kg.m²/s)
REAL*8,PARAMETER:: Navo     = 6.02214179d23               !Avogadro constant (/mol)
REAL*8,PARAMETER:: Temp_0K  = -273.16d0                   !Absolute zero of temperature (°C)
!
!Electromagnetism
REAL*8,PARAMETER:: e_charge = 1.60217646d-19              !Elementary charge (C)
REAL*8,PARAMETER:: c_light  = 299792458.d0                !Velocity of light (m/s)
REAL*8,PARAMETER:: mu_0     = 4.d-7*pi                    !vacuum permeability (kg.m/A²/s²)
REAL*8,PARAMETER:: eps_0    = 1.d0/(mu_0*c_light**2.d0)   !vacuum permittivity (A².s4/kg/m3)
!
!Materials
REAL*8,PARAMETER:: mass_amu = 1.660538782d-27             !Atomic mass unit (kg)
REAL*8,PARAMETER:: a_bohr   = 5.291772108d-11             !Bohr radius (m)
REAL*8,PARAMETER:: E_hartree= 4.35974417d-18              !1 Hartree (J)
REAL*8,PARAMETER:: E_rydberg= 2.1798741d-18               !1 Rydberg (J)
REAL*8,PARAMETER:: alpha_fine=mu_0*c_light*e_charge**2.d0                                  &
                 &            /(2.d0*h_planck)            !Fine-structure constant
!
!
!
END MODULE constants
