MODULE deterH
!
!**********************************************************************************
!*  DETERH                                                                        *
!**********************************************************************************
!* This module tries to determine the supercell vectors                           *
!* when they were not found in the input file.                                    *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 14 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
! WARNING: for now, this works only for rectangular or parallelepipedic boxes
!
!
CONTAINS
!
SUBROUTINE DETERMINE_H(inputfile)
!
USE comv
USE constants
USE messages
USE subroutines
!
IMPLICIT NONE
CHARACTER(LEN=128):: inputfile, test
CHARACTER(LEN=128):: msg, comment
INTEGER:: i, NP
REAL*8,DIMENSION(3):: P
!
!
!Initialize variables
NP = 0
 comment = 'File generated by pikashu'
H(:,:) = 0.d0
!
!
100 CONTINUE
msg = 'debug --> Entering DETERMINE_H...'
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
CALL CHECKFILE(inputfile,'read')
OPEN(UNIT=30,FILE=inputfile,FORM='FORMATTED',STATUS='OLD',POSITION='REWIND')
!
READ(30,*,END=150,ERR=150) NP
READ(30,*,END=150,ERR=150) test
GOTO 200
!
150 CONTINUE
WRITE(30,*) '0'
WRITE(30,*) TRIM(comment)
!
!
200 CONTINUE
!This loop works for parallelepipedic boxes only
DO i=1,NP
  READ(30,*,END=300,ERR=300) test, P(1), P(2), P(3)
  IF( P(1)>H(1,1) ) H(1,1) = P(1)
  IF( P(2)>H(2,2) ) H(2,2) = P(2)
  IF( P(3)>H(3,3) ) H(3,3) = P(3)
ENDDO
!
!
300 CONTINUE
!Increase the dimensions a bit
H(:,:) = H(:,:)*1.05d0
!
!Write the info at the end of file
WRITE(30,'(a4)') 'alat'
WRITE(30,'(a3)') '1.0'
WRITE(30,'(a9)') 'supercell'
WRITE(30,'(3(f12.6,2X))') H(1,1), H(1,2), H(1,3)
WRITE(30,'(3(f12.6,2X))') H(2,1), H(2,2), H(2,3)
WRITE(30,'(3(f12.6,2X))') H(3,1), H(3,2), H(3,3)
WRITE(30,*) 'cartesian coordinates'
GOTO 1000
!
!
!
800 CONTINUE
msg = 'X!X ERROR while reading the file'//TRIM(inputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
WRITE(msg,*) '    This apparently occured while reading atom # ', i
CALL DISPLAY_MSG(3,msg,logfile)
nerr = nerr+1
!
!
!
1000 CONTINUE
CLOSE(30)
CLOSE(35)
!
END SUBROUTINE DETERMINE_H
!
END MODULE deterH
