MODULE files
!
!**********************************************************************************
!*  FILES                                                                         *
!**********************************************************************************
!* This module contains subroutines performing special                            *
!* transformations on files for PIKASHU.                                          *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 07 June 2010                                     *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!* List of subroutines in this module:                                            *
!* SET_OUTPUT          sets one or all output to TRUE or FALSE                    *
!* FIND_INOUT          among 2files, determine which will be input or output      *
!**********************************************************************************
!
!
USE comv
USE constants
USE messages
!
IMPLICIT NONE
!
!
CONTAINS
!
!
!********************************************************
! SET_OUTPUT
! This subroutine sets output format(s) for PIKASHU
! to TRUE  or  FALSE
!********************************************************
SUBROUTINE SET_OUTPUT(extension,l_value)
!
IMPLICIT NONE
CHARACTER(LEN=3):: extension
CHARACTER(LEN=128):: msg
LOGICAL:: l_value  !TRUE or FALSE
!
SELECT CASE(extension)
CASE('xyz')
  output_xyz = l_value
CASE('cfg')
  output_cfg = l_value
CASE('xsf')
  output_xsf = l_value
CASE('gin')
  output_gin = l_value
CASE('pos')
  output_poscar = l_value
! -- add other formats here --
!
CASE('all')
  output_xyz = l_value
  output_cfg = l_value
  output_xsf = l_value
  output_gin = l_value
  output_poscar = l_value
  ! -- add other formats here --
!
CASE DEFAULT
  msg = 'X!X ERROR: this file format was not recognized: '//extension
  CALL DISPLAY_MSG(3,msg,logfile)
  nerr = nerr+1
!
END SELECT
!
END SUBROUTINE SET_OUTPUT
!
!
!********************************************************
! FIND_INOUT
! This subroutine, provided two file names, determines
! which file(s) exist. The existing file will become
! the "inputfile", and the non-existing one will become
! the "outputfile". If both files exist (or do not exist)
! then the user is prompted which file to use as
! "inputfile".
!********************************************************
SUBROUTINE FIND_INOUT(inputfile,outputfile)
!
IMPLICIT NONE
CHARACTER(LEN=64):: test, inputfile,outputfile
CHARACTER(LEN=128):: msg
LOGICAL:: fileexists
INTEGER:: i
!
test = ''
!
IF(inputfile.NE.'') THEN
    INQUIRE(FILE=inputfile,EXIST=fileexists)
    IF(fileexists) THEN
      INQUIRE(FILE=outputfile,EXIST=fileexists)
      IF(fileexists) THEN
        !If both inputfile and outputfile already exist, we're in trouble:
        !we have to ask the user what to do
        msg = '/!\ Both files exist: '//TRIM(inputfile)//' and '//TRIM(outputfile)
        CALL DISPLAY_MSG(3,msg,logfile)
        msg = '(°< Please tell which one you want to use as input file:'
        CALL DISPLAY_MSG(3,msg,logfile)
        msg = '    1- '//TRIM(inputfile)
        CALL DISPLAY_MSG(3,msg,logfile)
        msg = '    2- '//TRIM(outputfile)
        CALL DISPLAY_MSG(3,msg,logfile)
        READ(*,*) i
        IF(i==1) THEN
          inputfile = TRIM(inputfile)
          outputfile = TRIM(outputfile)
        ELSEIF(i>=2) THEN
          test = inputfile
          inputfile = outputfile
          outputfile = test
        ENDIF
      ELSE
        !if outputfile doesn't exist then inputfile is the input file
        inputfile = TRIM(inputfile)
        outputfile = TRIM(outputfile)
      ENDIF
    !
    ELSE !i.e. if inputfile doesn't exist
      INQUIRE(FILE=outputfile,EXIST=fileexists)
      IF(fileexists) THEN
        !If outputfile exists then it is the input file
        test = inputfile
        inputfile = outputfile
        outputfile = test
      ELSE
        !If none of the files specified by the user exist, we're in trouble:
        !we have to ask the user what to do
        msg = '/!\ None of these files exist: '//TRIM(inputfile)//' nor '//TRIM(outputfile)
        CALL DISPLAY_MSG(3,msg,logfile)
        msg = '(°< Please provide the name of an existing file:'
        CALL DISPLAY_MSG(3,msg,logfile)
        READ(*,*) inputfile
        outputfile = ''
      ENDIF
    ENDIF
  ELSE !i.e. if file1=='' (which also implies that file2=='')
    msg = '/!\ No input file was specified.'
    CALL DISPLAY_MSG(3,msg,logfile)
    msg = '(°< Please provide the name of an existing file:'
    CALL DISPLAY_MSG(3,msg,logfile)
    READ(*,*) inputfile
    outputfile = ''
  ENDIF
!
END SUBROUTINE FIND_INOUT
!
!
!
!
END MODULE files
