MODULE functions
!
!**********************************************************************************
!*  FUNCTIONS                                                                     *
!**********************************************************************************
!* This module contains functions commonly used by several                        *
!* parts of the PIKASHU program.                                                  *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 17 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater:          *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!**********************************************************************************
!* List of functions in this file:                                                *
!* ANGVEC              calculates angle between 2 vectors from a matrix           *
!**********************************************************************************
!
!
USE comv
USE constants
!
!
CONTAINS
!
!
!********************************************************
!  ANGVEC
!  This function calculates the angle between two vectors
!  V1 and V2. Angle theta is returned in radians.
!********************************************************
!
FUNCTION ANGVEC(V1,V2) RESULT(theta)
!
IMPLICIT NONE
REAL*8, DIMENSION(3):: V1, V2
REAL*8:: theta
!
theta = DACOS( DOT_PRODUCT(V1,V2) /                                    &
      &        ( DSQRT(DOT_PRODUCT(V1,V1))*DSQRT(DOT_PRODUCT(V2,V2)) ) &
      &      )
!
RETURN
!
END FUNCTION ANGVEC
!
!
END MODULE functions
