MODULE in_cfg
!
!**********************************************************************************
!*  IN_CFG                                                                        *
!**********************************************************************************
!* This modules reads Ju Li's CFG atomic position files.                          *
!* The CFG format is described here:                                              *
!*    http://mt.seas.upenn.edu/Archive/Graphics/A/#standard_CFG                   *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 17 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE READ_CFG(inputfile)
!
CHARACTER(LEN=2):: spieces
CHARACTER(LEN=64):: inputfile
CHARACTER(LEN=64):: comment, temp
CHARACTER(LEN=128):: msg
INTEGER:: doneheader
INTEGER:: NP, NPcount
REAL*8:: a0, smass
REAL*8:: testreal
REAL*8:: P1, P2, P3
REAL*8, DIMENSION(4):: P
!
!
!Initialize some variables
 comment = 'File generated by pikashu'
doneheader = 0
a0 = 1.d0
NP=0
NPcount=0
testreal = 0.d0
P(:)=0.d0
H(:,:) = 0.d0
!
!
!
100 CONTINUE
OPEN(UNIT=30,FILE=inputfile,FORM='FORMATTED',STATUS='OLD',ERR=200)
OPEN(UNIT=35,FILE='pikashu.xyz',FORM='FORMATTED',STATUS='UNKNOWN',ERR=200)
!
!Read the preamble of the file
doneheader = 0
DO WHILE(doneheader<11)
  READ(30,'(a64)',ERR=400,END=400) temp
  temp = ADJUSTL(temp)
  IF(temp(1:1).NE.'#' .AND. temp(2:2).NE.'#') THEN
    !Check if it is a new spieces
    IF(temp(1:21)=='Number of particles =') THEN
        READ(temp(22:40),*) NP
        WRITE(35,*) NP
        WRITE(35,*) comment
        doneheader = doneheader+1
    ELSEIF(temp(1:2)=='A=' .OR. temp(1:3)=='A =') THEN
        READ(temp(4:10),*,ERR=400,END=400) testreal
        a0 = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(1,1)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(1,1) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(1,2)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(1,2) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(1,3)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(1,3) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(2,1)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(2,1) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(2,2)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(2,2) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(2,3)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(2,3) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(3,1)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(3,1) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(3,2)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(3,2) = testreal
        doneheader = doneheader+1
    ELSEIF(temp(1:7)=='H0(3,3)') THEN
        READ(temp(10:64),*,ERR=400,END=400) testreal
        H(3,3) = testreal
        doneheader = doneheader+1
        Hset = .TRUE.
    ENDIF
  !
  ENDIF  !Endif #
  !
  150 CONTINUE
  msg = 'debug --> CFG header: '//TRIM(temp)
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !
ENDDO
160 FORMAT(f6.2,X,3(f10.6,2x))
!
H(:,:) = a0*H(:,:)
!
!
!
200 CONTINUE
P(4) = 0.d0
msg = 'debug --> Finding the starting point for atomic positions...'
CALL DISPLAY_MSG(verbosity,msg,logfile)
!Let's make sure to be placed at the beginning of atomic positions
DO WHILE(P(4)==0.d0)
  READ(30,'(a64)') temp
  !try to read a real
  READ(temp,*,ERR=201,END=201) testreal
  !No error? Then the real was most probably an atom mass
  !To confirm that, let's try to read the atom spieces on the
  !next line and see if it matches
  smass = testreal
  CALL ATOMSPIECES(smass,spieces)
  temp = spieces
  READ(30,*) spieces
  IF(TRIM(ADJUSTL(temp))==spieces) P(4) = smass
  201 CONTINUE
ENDDO
!
!Now, read all atomic coordinates and write them in pikashu.xyz
msg = 'debug --> Reading atomic positions'
CALL DISPLAY_MSG(verbosity,msg,logfile)
DO
  P(1:3) = 0.d0
  !We read the line
  READ(30,'(a64)',ERR=300,END=300) temp
  temp = TRIM(ADJUSTL(temp))
  !
  IF(temp(1:1).NE.'#') THEN
    !If we can read 3 coordinates then its an atomic position
    READ(temp,*,ERR=250,END=250) P1, P2, P3
    NPcount=NPcount+1
    !Convert frac.coordinates into cartesian
    P(1) = P1*H(1,1)+P2*H(2,1)+P3*H(3,1)
    P(2) = P1*H(1,2)+P2*H(2,2)+P3*H(3,2)
    P(3) = P1*H(1,3)+P2*H(2,3)+P3*H(3,3)
    !Write coordinates in pikashu.xyz
    WRITE(35,160) P(4), P(1), P(2), P(3)
    !Jump to the next line of the CFG file
    GOTO 260
    !
    250 CONTINUE
    !If we cannot read 3 coordinates then it has to be the
    !lines indicating a new spieces; let's check that
    READ(temp,*,ERR=400,END=400) testreal   !First line is atomic mass
    READ(30,'(a64)',ERR=400,END=400) temp   !Second line is atomic spieces
    spieces = TRIM(ADJUSTL(temp))
    CALL ATOMMASS(spieces,smass)
    !Check if everything matches
    IF(smass==testreal) THEN
      P(4) = smass
    ELSE
      WRITE(msg,*) 'X!X ERROR in determining atomic spieces: ', TRIM(temp)
      CALL DISPLAY_MSG(3,msg,logfile)
      GOTO 400
    ENDIF
  ENDIF
  260 CONTINUE
ENDDO
!
!
!
300 CONTINUE
IF(NPcount.NE.NP) THEN
  WRITE(msg,*) 'X!X ERROR: number of atoms read:', NPcount
  CALL DISPLAY_MSG(3,msg,logfile)
  WRITE(msg,*) '           number of atoms declared:', NP
  CALL DISPLAY_MSG(3,msg,logfile)
  GOTO 400
ENDIF
!Write extended info at end of pikashu.xyz
WRITE(35,'(a4)') 'alat'
WRITE(35,'(a3)') '1.0'
WRITE(35,'(a9)') 'supercell'
WRITE(35,'(3(f12.6,2X))') H(1,1), H(1,2), H(1,3)
WRITE(35,'(3(f12.6,2X))') H(2,1), H(2,2), H(2,3)
WRITE(35,'(3(f12.6,2X))') H(3,1), H(3,2), H(3,3)
!
!
350 CONTINUE
CLOSE(30)
CLOSE(35)
GOTO 500
!
!
!
400 CONTINUE
CLOSE(30)
CLOSE(35)
msg = 'X!X ERROR: there was an error while parsing the file '//TRIM(inputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
IF(NPcount<=0) THEN
  WRITE(msg,*) '   Data appears to have an unrecognized format.'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
ELSE
  WRITE(msg,451) '   This apparently occured when reading atom #', NPcount
  CALL DISPLAY_MSG(verbosity,msg,logfile)
ENDIF
451 FORMAT(a46,i7)
nerr = nerr+1
!
!
!
500 CONTINUE
!
END SUBROUTINE READ_CFG
!
!
END MODULE in_cfg
