MODULE in_xsf
!
!
!**********************************************************************************
!*  IN_XSF                                                                        *
!**********************************************************************************
!* This module reads XSF format, initially designed for XCrysDen.                 *
!* The XSF format is described here:                                              *
!*    http://www.xcrysden.org/doc/XSF.html                                        *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 19 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE READ_XSF(inputfile)
!
CHARACTER(LEN=4):: xyzcoord
CHARACTER(LEN=7):: xyzformat
CHARACTER(LEN=64):: inputfile
CHARACTER(LEN=64):: comment
CHARACTER(LEN=128):: test, msg
INTEGER:: i, NP
REAL*8:: a0
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
NP = 0
a0 = 1.d0
P(:) = 0.d0
xyzformat = 'massxyz'
xyzcoord = 'cart'
 comment = 'File generated by pikashu'
!
100 CONTINUE
OPEN(UNIT=30,FILE=inputfile,FORM='FORMATTED',STATUS='OLD')
OPEN(UNIT=35,FILE='pikashu.xyz',FORM='FORMATTED',STATUS='UNKNOWN')
!
i=-1
DO WHILE(NP==0)
  READ(30,'(a128)') test
  test = TRIM(ADJUSTL(test))
  IF(test(1:7)=='PRIMVEC') THEN
    READ(30,*,ERR=400,END=400) H(1,1), H(1,2), H(1,3)
    READ(30,*,ERR=400,END=400) H(2,1), H(2,2), H(2,3)
    READ(30,*,ERR=400,END=400) H(3,1), H(3,2), H(3,3)
    Hset = .TRUE.
  ELSEIF(test(1:9)=='PRIMCOORD') THEN
    READ(30,*,ERR=400,END=400) NP
  ENDIF
ENDDO
!
200 CONTINUE
!Write header in pikashu.xyz
WRITE(35,*) NP
WRITE(35,*) comment
!
!Read atomic positions and write them to pikashu.xyz
DO i=1,NP
  READ(30,*,ERR=400,END=400) P(4), P(1), P(2), P(3)
  WRITE(35,220) P(4), P(1), P(2), P(3)
ENDDO
220 FORMAT(f8.4,X,3(f10.6,2x))
!
!
!
300 CONTINUE
!Write info at end of pikashu.xyz
WRITE(35,'(a4)') 'alat'
WRITE(35,'(a3)') '1.0'
WRITE(35,'(a9)') 'supercell'
WRITE(35,'(3(f12.6,2X))') H(1,1), H(1,2), H(1,3)
WRITE(35,'(3(f12.6,2X))') H(2,1), H(2,2), H(2,3)
WRITE(35,'(3(f12.6,2X))') H(3,1), H(3,2), H(3,3)
GOTO 500
!
!
!
400 CONTINUE
msg = 'X!X ERROR: there was an error while parsing the file '//TRIM(inputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
IF(i<=0) THEN
  WRITE(msg,*) '   Data appears to have an unrecognized format.'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
ELSE
  WRITE(msg,451) '   This apparently occured when reading atom #', i
  CALL DISPLAY_MSG(verbosity,msg,logfile)
ENDIF
451 FORMAT(a46,i7)
nerr = nerr+1
GOTO 500
!
!
!
500 CONTINUE
CLOSE(30)
CLOSE(35)
!
END SUBROUTINE READ_XSF
!
END MODULE in_xsf
