MODULE mode_create
!
!**********************************************************************************
!*  MODE_CREATE                                                                   *
!**********************************************************************************
!* This module creates an atomic structure based on some keywords.                *
!* Then it outputs a file in the extended XYZ format.                             *
!**********************************************************************************
!* (C) March 2010 - Pierre Hirel                                                  *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 12 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE messages
USE files
USE subroutines
USE mode_normal
!
CONTAINS
!
!
SUBROUTINE CREATE_CELL(create_a0,create_struc,create_spieces,outputfile)
!
!
IMPLICIT NONE
CHARACTER(LEN=3):: outfileformat
CHARACTER(LEN=10):: create_struc
CHARACTER(LEN=2),DIMENSION(20):: create_spieces
CHARACTER(LEN=128):: outputfile, temp
CHARACTER(LEN=128):: msg
INTEGER:: i, m, nspieces
REAL*8,DIMENSION(4):: P
REAL*8:: create_a0
!
!Initialize variables
m = 1
nspieces = 0
P(:) = 0.d0
!
!
msg = ">>> Creating system:"
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
100 CONTINUE
!Make the create_struc variable straight
!in case the user mistyped 'diamand' or 'pervoskite'
IF(create_struc(1:2)=='di') THEN
  create_struc = 'diamond'
ELSEIF(create_struc(1:2)=='pe') THEN
  create_struc = 'perovskite'
ELSEIF(create_struc(1:2)=='zi' .OR. create_struc(1:2)=='zb') THEN
  create_struc = 'zincblende'
ENDIF
!
!Determine the number of spieces
DO i=1,20
  IF(create_spieces(i).NE.'') nspieces=nspieces+1
ENDDO
!
!If the user specified an extension that is not XYZ, we modify that
outputfile = TRIM(ADJUSTL(outputfile))
!
!
!
200 CONTINUE
!First we create the structure in extended XYZ format
OPEN(UNIT=31,FILE='pikashu_create.xyz',FORM='FORMATTED',STATUS='UNKNOWN')
!
SELECT CASE(create_struc)
!
CASE('sc')
  WRITE(31,'(a1)') '1'
  WRITE(31,*) create_spieces(1), ' with simple cubic structure'
  WRITE(msg,*) "..> ", create_spieces(1), ' with simple cubic structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a12)') P(4), '  0   0   0 '
  WRITE(31,'(a4)') 'alat'
  WRITE(31,'(f12.8)') create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
CASE('bcc')
  WRITE(31,'(a1)') '2'
  WRITE(31,*) create_spieces(1), ' with bcc structure'
  WRITE(msg,*) "..> ", create_spieces(1), ' with bcc structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a12)') P(4), '  0   0   0 '
  WRITE(31,'(f5.2,a12)') P(4), ' 0.5 0.5 0.5'
  WRITE(31,'(a4)') 'alat'
  WRITE(31,'(f12.8)') create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
CASE('fcc')
  WRITE(31,'(a1)') '4'
  WRITE(31,*) create_spieces(1), ' with fcc structure'
  WRITE(msg,*) "..> ", create_spieces(1), ' with fcc structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a12)') P(4), '  0   0   0 '
  WRITE(31,'(f5.2,a12)') P(4), ' 0.5 0.5  0 '
  WRITE(31,'(f5.2,a12)') P(4), '  0  0.5 0.5'
  WRITE(31,'(f5.2,a12)') P(4), ' 0.5  0  0.5'
  WRITE(31,'(a4)') 'alat'
  WRITE(31,'(f12.8)') create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
CASE('dia','diamond')
  WRITE(31,'(a1)') '8'
  WRITE(31,*) create_spieces(1), ' with diamond structure'
  WRITE(msg,*) "..> ", create_spieces(1), ' with diamond structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a15)') P(4), '  0    0    0  '
  WRITE(31,'(f5.2,a15)') P(4), ' 0.5  0.5   0  '
  WRITE(31,'(f5.2,a15)') P(4), ' 0.5   0   0.5 '
  WRITE(31,'(f5.2,a15)') P(4), '  0   0.5  0.5 '
  WRITE(31,'(f5.2,a15)') P(4), ' 0.25 0.25 0.25'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.75 0.75 0.25'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.75 0.25 0.75'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.25 0.75 0.75'
  WRITE(31,'(a4)') 'alat'
  WRITE(31,'(f12.8)') create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
CASE('zb','zincblende')
  WRITE(31,'(a1)') '8'
  temp = TRIM(create_spieces(1))//TRIM(create_spieces(2))
  WRITE(31,*) TRIM(temp), ' with zincblende structure'
  WRITE(msg,*) "..> ", TRIM(temp), ' with zincblende structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a15)') P(4), '  0    0    0  '
  WRITE(31,'(f5.2,a15)') P(4), ' 0.5  0.5   0  '
  WRITE(31,'(f5.2,a15)') P(4), ' 0.5   0   0.5 '
  WRITE(31,'(f5.2,a15)') P(4), '  0   0.5  0.5 '
  CALL ATOMMASS(create_spieces(2),P(4))
  WRITE(31,'(f5.2,a15)') P(4), ' 0.25 0.25 0.25'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.75 0.75 0.25'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.75 0.25 0.75'
  WRITE(31,'(f5.2,a15)') P(4), ' 0.25 0.75 0.75'
  WRITE(31,'(a4)') 'alat'
  WRITE(31,'(f12.8)') create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
CASE('per','perovskite')
  WRITE(31,'(a1)') '5'
  temp = TRIM(create_spieces(1))//TRIM(create_spieces(2))//TRIM(create_spieces(3))
  WRITE(31,*) 'Perovskite ', TRIM(temp), '3'
  WRITE(msg,*) "..> ", TRIM(temp), '3 with cubic perovskite structure'
  CALL ATOMMASS(create_spieces(1),P(4))
  WRITE(31,'(f5.2,a12)') P(4), ' 0.5 0.5 0.5'
  CALL ATOMMASS(create_spieces(2),P(4))
  WRITE(31,'(f5.2,a12)') P(4), '  0   0   0 '
  CALL ATOMMASS(create_spieces(3),P(4))
  WRITE(31,'(f5.2,a12)') P(4), ' 0.5  0   0 '
  WRITE(31,'(f5.2,a12)') P(4), '  0  0.5  0 '
  WRITE(31,'(f5.2,a12)') P(4), '  0   0  0.5'
  WRITE(31,*) 'alat'
  WRITE(31,*) create_a0
  WRITE(31,'(a9)') 'supercell'
  WRITE(31,'(a5)') '1 0 0'
  WRITE(31,'(a5)') '0 1 0'
  WRITE(31,'(a5)') '0 0 1'
!
! -- add other structures here --
!
CASE DEFAULT
  nerr = nerr+1
  msg = 'X!X ERROR: unknown structure: '//TRIM(create_struc)
  CALL DISPLAY_MSG(3,msg,logfile)
  GOTO 1000
!
END SELECT
!
CLOSE(31)
!
msg = TRIM(ADJUSTL(msg))
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
msg = "..> System was successfuly created."
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
300 CONTINUE
!Then we convert the created system to the format asked by the user
temp = 'pikashu_create.xyz'
CALL CONVERT_AFF(temp,outputfile,outfileformat)
!
CALL SYSTEM('rm -f pikashu_create.xyz')
!
!
!
500 CONTINUE
!
!
!
1000 CONTINUE
!
!
!
END SUBROUTINE CREATE_CELL
!
!
END MODULE mode_create
