MODULE mode_interactive
!
!**********************************************************************************
!*  MODE_INTERACTIVE                                                              *
!**********************************************************************************
!* This module interacts with the user to know what to do.                        *
!**********************************************************************************
!* (C) May 2010 - Pierre Hirel                                                    *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 12 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE messages
USE files
USE subroutines
USE guess_form
USE mode_normal
!
CONTAINS
!
!
SUBROUTINE INTERACT()
!
!
IMPLICIT NONE
CHARACTER(LEN=3):: infileformat, outfileformat
CHARACTER(LEN=128):: file1, file2, test
CHARACTER(LEN=128):: msg
!
!Initialize variables
!
msg = 'debug --> Entering INTERACT'
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
100 CONTINUE
msg = '/!\ No command-line argument were found.'
CALL DISPLAY_MSG(3,msg,logfile)
msg = '(°< Enter the name of the file you want to convert:'
CALL DISPLAY_MSG(3,msg,logfile)
msg = "    (type 'ls' for a list of files of current directory)"
CALL DISPLAY_MSG(3,msg,logfile)
READ(*,*) test
IF(TRIM(ADJUSTL(test))=='ls') THEN
  CALL SYSTEM('ls')
  msg = '(°< Enter the name of a file you want to convert:'
  CALL DISPLAY_MSG(3,msg,logfile)
  READ(*,*) file1
ELSE
  file1 = TRIM(ADJUSTL(test))
ENDIF
!Check if input file exists and has a recognizable shape
CALL CHECKFILE(file1,'read')
CALL GUESS_FORMAT(file1,infileformat)
msg = '>>> Input file format: '//infileformat
CALL DISPLAY_MSG(verbosity,msg,logfile)
IF(infileformat=='xxx') THEN
  nerr=nerr+1
  msg = 'X!X ERROR: I could not guess the format of the input file!'
  CALL DISPLAY_MSG(3,msg,logfile)
  msg = '    Maybe it is a format unsupported by pikashu yet?'
  CALL DISPLAY_MSG(3,msg,logfile)
  msg = '    Anyway it appears I cannot help, I will terminate.'
  CALL DISPLAY_MSG(3,msg,logfile)
  GOTO 1000
ENDIF
!
msg = '(°< To which format do you want to convert it?'
CALL DISPLAY_MSG(3,msg,logfile)
msg = '    '//TRIM(listofformats)
CALL DISPLAY_MSG(3,msg,logfile)
READ(*,*) outfileformat
CALL SET_OUTPUT(outfileformat,.TRUE.)
IF(nerr>0) GOTO 500
CALL NAME_OUTFILE(file1,file2,outfileformat)
!
msg = 'debug --> mode, file1, file2: '//TRIM(mode)//TRIM(file1)//TRIM(file2)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
200 CONTINUE
!Now convert the file according to what the user asked
CALL CONVERT_AFF(file1,file2,outfileformat)
!
!
!
500 CONTINUE
!
!
!
1000 CONTINUE
!
!
!
END SUBROUTINE INTERACT
!
!
END MODULE mode_interactive
