MODULE mode_merge
!
!**********************************************************************************
!*  MODE_MERGE                                                                    *
!**********************************************************************************
!* This module reads two files in the extended XYZ format and                     *
!* merges them, i.e. writes all atomic positions in one single file.              *
!**********************************************************************************
!* (C) March 2010 - Pierre Hirel                                                  *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 14 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE subroutines
USE deterh
USE messages
USE files
USE mode_normal
!
!
CONTAINS
!
!
SUBROUTINE MERGE_XYZ(firstxyz,secondxyz,outputfile)
!
!
IMPLICIT NONE
CHARACTER(LEN=3):: outfileformat
CHARACTER(LEN=128):: firstxyz, secondxyz, file, outputfile
CHARACTER(LEN=128):: temp, msg, comment
LOGICAL:: reduced
INTEGER:: i, NP1, NP2
REAL*8:: a0
REAL*8:: x1, y1, z1
!
!
!Initialize variables
a0 = 1.d0        !If lattice parameter is not specified, default has to be 1
H(:,:) = 0.d0
Hset=.FALSE.
reduced=.FALSE.  !By default, XYZ format uses cartesian coordinates
file = firstxyz
!
!
msg = '>>> Merging the files '//TRIM(firstxyz)//' and '//TRIM(secondxyz)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
100 CONTINUE
!Open first XYZ file
OPEN(UNIT=30,FILE=firstxyz,FORM='FORMATTED',STATUS='OLD',POSITION='REWIND')
!Open second XYZ file
OPEN(UNIT=31,FILE=secondxyz,FORM='FORMATTED',STATUS='OLD',POSITION='REWIND')
!
!Open output file
OPEN(UNIT=35,FILE='pikashu_merge.xyz',FORM='FORMATTED',STATUS='UNKNOWN')
REWIND(30)
REWIND(31)
READ(30,*,ERR=800,END=800) NP1
READ(30,'(a128)',ERR=800,END=800) comment
READ(31,*,ERR=800,END=800) NP2
READ(31,*,ERR=800,END=800) temp
!
!
!Write header for xyz file
WRITE(35,*) NP1+NP2
WRITE(35,*) TRIM(comment)
!
!Copy atomic positions
file = firstxyz
DO i=1,NP1
  READ(30,*,ERR=800,END=800) temp, x1, y1, z1
  WRITE(35,150) TRIM(temp), x1, y1, z1
ENDDO
!
file = secondxyz
DO i=1,NP2
  READ(31,*,ERR=800,END=800) temp, x1, y1, z1
  WRITE(35,150) TRIM(temp), x1, y1, z1
ENDDO
150 FORMAT(a12,2X,3(f12.6,2X))
!
CLOSE(30)
CLOSE(31)
CLOSE(35)
!
!
!
200 CONTINUE
!Try to guess the new vectors of the supercell
temp = 'pikashu_merge.xyz'
CALL DETERMINE_H(temp)
!
!Write footer of XYZ file
OPEN(UNIT=35,FILE='pikashu_merge.xyz',FORM='FORMATTED',STATUS='OLD',POSITION='APPEND')
WRITE(35,'(a4)') 'alat'
WRITE(35,'(a3)') '1.0'
WRITE(35,'(a9)') 'supercell'
WRITE(35,'(3(f12.6,X))') H(1,1), H(1,2), H(1,3)
WRITE(35,'(3(f12.6,X))') H(2,1), H(2,2), H(2,3)
WRITE(35,'(3(f12.6,X))') H(3,1), H(3,2), H(3,3)
CLOSE(35)
!
!
!
400 CONTINUE
temp = 'pikashu_merge.xyz'
CALL CONVERT_AFF(temp,outputfile,outfileformat)
!
!
!
500 CONTINUE
CALL SYSTEM('rm -f pikashu_merge.xyz')
!
msg = '..> I wrote the file: '//TRIM(outputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
GOTO 1000
!
!
!
800 CONTINUE
msg = 'X!X ERROR while reading the file '//TRIM(file)
CALL DISPLAY_MSG(3,msg,logfile)
WRITE(msg,*) '    This apparently occured while reading atom # ', i
CALL DISPLAY_MSG(3,msg,logfile)
nerr = nerr+1
GOTO 1000
!
!
!
1000 CONTINUE
IF(verbosity<4) CALL SYSTEM('rm -f pikashu_merge*')
!
!
END SUBROUTINE MERGE_XYZ
!
!
END MODULE mode_merge
