MODULE modes
!
!
!**********************************************************************************
!*  MODES                                                                         *
!**********************************************************************************
!* This module deals with the different modes that pikashu                        *
!* can run.                                                                       *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 31 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE messages
USE files
USE subroutines
USE mode_normal
USE cut_cell
USE out_dd
USE xyz_difference
USE mode_merge
USE readin
!
!
CONTAINS
!
!
SUBROUTINE RUN_MODE(file1,file2,filefirst,filesecond,outfileformat)
!
IMPLICIT NONE
CHARACTER(LEN=3):: outfileformat, list_outfileformat
CHARACTER(LEN=128):: file1, file2  !should be inputfile, ouputfile (or vice-versa)
CHARACTER(LEN=128):: listfile      !used by mode 'filelist'
CHARACTER(LEN=128):: filefirst, filesecond !used by modes 'ddplot' and 'merge'
CHARACTER(LEN=128):: inputfile, outputfile
CHARACTER(LEN=128):: firstxyz, secondxyz
CHARACTER(LEN=128):: msg, test
LOGICAL:: fileexists
INTEGER:: strlength
!
!
!Initialize variables
inputfile=''
outputfile=''
!
!
!Find an outfileformat to start with
!
!
100 CONTINUE
msg = 'debug --> running mode: '//TRIM(mode)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!  NORMAL MODE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
IF(mode=='normal') THEN
  msg = 'debug --> Mode normal'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !Normal mode: we just convert a single file to another format.
  !
  !If inputfile is not known already, and if file1 and/or file2
  ! were specified as command-line parameters, then figure out which
  ! one is the input file and which one is the output file
  IF(inputfile=='') THEN
    file1 = TRIM(ADJUSTL(file1))
    file2 = TRIM(ADJUSTL(file2))
    msg = 'debug --> file1, file2: '//TRIM(file1)//', '//TRIM(file2)
    CALL DISPLAY_MSG(verbosity,msg,logfile)
    !
    IF(mode=='normal') CALL FIND_INOUT(file1,file2)
    !
    inputfile = TRIM(ADJUSTL(file1))
    outputfile = TRIM(ADJUSTL(file2))
    msg = 'debug --> Inputfile, outputfile: '//TRIM(inputfile)//', '//TRIM(outputfile)
    CALL DISPLAY_MSG(verbosity,msg,logfile)
  ENDIF
  !
  !If output file name is still blanck, build one
  IF(outputfile=='') THEN
    CALL NAME_OUTFILE(inputfile,outputfile,outfileformat)
  ENDIF
  !
  !We can now convert the inputfile into outputfile
  !The "outfileformat" parameter here is dummy, since the variables
  !for output (output_xyz, output_cfg, etc.) are passed to the
  !subroutine CONVERT_AFF
  msg = 'debug --> outfileformat: '//outfileformat
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  CALL CONVERT_AFF(inputfile,outputfile,outfileformat)
!
!
200 CONTINUE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!  LIST MODE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
ELSEIF(mode=='list') THEN
  msg = 'debug --> list'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  listfile = file1
  !List mode:
  !in this mode the program has to read a file containing
  !a list of files to convert.
  CALL CHECKFILE(listfile,'read')
  msg = '>>> Using list file: '//TRIM(listfile)
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  OPEN(UNIT=50,FILE=listfile,STATUS='OLD',FORM='FORMATTED')
  DO
    !If no output format is specified, XYZ is used by default
    IF(outfileformat=='') outfileformat = 'xyz'
    READ(50,'(a128)',ERR=235,END=235) test
    list_outfileformat = outfileformat
    test = ADJUSTL(test)
    IF(LEN_TRIM(test).NE.0 .AND. test(1:1).NE.'#') THEN
      IF(test(1:3)=='all') THEN
        !'all <format>' means that all the following files have to be converted
        !into the <format> by default
        READ(test(4:20),*) outfileformat
        list_outfileformat = TRIM(ADJUSTL(outfileformat))
        CALL SET_OUTPUT(outfileformat,.TRUE.)
        msg = '>>> Converting all following files to: '//TRIM(outfileformat)
        CALL DISPLAY_MSG(verbosity,msg,logfile)
      ELSE
        !On a line there should be an input file name (mandatory)
        !and a format (optional)
        READ(test,*) inputfile
        !We check if the input file exists
        INQUIRE(FILE=inputfile,EXIST=fileexists)
        IF(fileexists) THEN
          !We check if the user specified a format for the output file
          strlength = LEN_TRIM(inputfile)
          READ(test(strlength+1:128),*,END=231,ERR=231) list_outfileformat
          CALL SET_OUTPUT(list_outfileformat,.TRUE.)
          !
          !If the format specified is different from 'outfileformat',
          !then use this particular format just for this file
          231 CONTINUE
          IF(list_outfileformat=='') list_outfileformat = outfileformat
          msg = 'debug --> outfileformat, list_outfileformat: '//TRIM(outfileformat)//', '//TRIM(list_outfileformat)
          CALL DISPLAY_MSG(verbosity,msg,logfile)
          WRITE(msg,*) 'debug --> ', output_xsf, output_cfg
          CALL DISPLAY_MSG(verbosity,msg,logfile)
          !
          !Now we know the input file and the format to convert it to
          CALL NAME_OUTFILE(inputfile,outputfile,list_outfileformat)
          CALL CONVERT_AFF(inputfile,outputfile,list_outfileformat)
          IF(list_outfileformat.NE.outfileformat)                          &
            &    CALL SET_OUTPUT(list_outfileformat,.FALSE.)
        ELSE
          msg = '/!\ WARNING: This file does not exist: '//TRIM(inputfile)
          CALL DISPLAY_MSG(verbosity,msg,logfile)
          msg = '    Skipping...'
          CALL DISPLAY_MSG(verbosity,msg,logfile)
        ENDIF
      ENDIF
      msg = '            --===============--'
      CALL DISPLAY_MSG(verbosity,msg,logfile)
    ENDIF
  ENDDO
  235 CONTINUE
  CLOSE(50)
!
!
300 CONTINUE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!  DDPLOT MODE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
ELSEIF(mode=='ddplot') THEN
  CALL SET_OUTPUT('all',.FALSE.)
  msg = 'debug --> Mode ddplot'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !DDplot mode:
  !in this mode the program has to read 2 files (no matter their format)
  !and create a file for ddplot.
  msg = '>>> Using ddplot mode.'
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !Check if the files exit
  CALL CHECKFILE(filefirst,'read')
  CALL CHECKFILE(filesecond,'read')
  outputfile = TRIM(ADJUSTL(file1))
  IF(outputfile=='') CALL NAME_OUTFILE(filesecond,outputfile,'dd ')
  IF(.NOT. overw) CALL CHECKFILE(outputfile,'writ')
  overw = .TRUE.
  !convert the two input files to XYZ
  firstxyz = 'pikashu_dd1.xyz'
  CALL READ_AFF(filefirst,firstxyz)
  secondxyz = 'pikashu_dd2.xyz'
  CALL READ_AFF(filesecond,secondxyz)
  !
  !Use the two XYZ files to produce the DD file
  CALL WRITE_DD(firstxyz,secondxyz,outputfile)
  IF(verbosity<4) CALL SYSTEM('rm -f pikashu_dd*.xyz')
!
!
400 CONTINUE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!  DIFFERENCE MODE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
ELSEIF(mode=='diff') THEN
  CALL SET_OUTPUT('all',.FALSE.)
  msg = 'debug --> DIFF mode: file1,file2: '//TRIM(file1)//', '//TRIM(file2)
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !
  !Difference mode:
  !in this mode the program reads two files (no matter their format)
  !converts them to extended XYZ, and calculates the difference
  !in atomic positions
  CALL CHECKFILE(file1,'read')
  CALL CHECKFILE(file2,'read')
  !
  !Convert first file to XYZ
  firstxyz = 'pikashu_diff1.xyz'
  CALL READ_AFF(file1,firstxyz)
  IF(nerr>=1) GOTO 450
  !Convert second file to XYZ
  secondxyz = 'pikashu_diff2.xyz'
  CALL READ_AFF(file2,secondxyz)
  IF(nerr>=1) GOTO 450
  !Calculate the difference between the two XYZ files
  CALL DIFF_XYZ(firstxyz,secondxyz)
  IF(nerr>=1) GOTO 450
  IF(verbosity<4) CALL SYSTEM('rm -f pikashu_diff*.xyz')
  !
  450 CONTINUE
!
!
!
500 CONTINUE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!  MERGE MODE
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
ELSEIF(mode=='merge') THEN
  !CALL SET_OUTPUT('all',.FALSE.)
  !outfileformat = 'xyz'
  outputfile = TRIM(ADJUSTL(file1))
  IF(outputfile=='') CALL NAME_OUTFILE(filefirst,outputfile,outfileformat)
  msg = 'debug --> MERGE mode: file1,file2: '//TRIM(file1)//', '//TRIM(file2)
  CALL DISPLAY_MSG(verbosity,msg,logfile)
  !
  !Check if files exist
  CALL CHECKFILE(filefirst,'read')
  CALL CHECKFILE(filesecond,'read')
  IF(.NOT.overw) CALL CHECKFILE(outputfile,'writ')
  !
  !Convert the two files to XYZ
  firstxyz = 'pikashu_merge1.xyz'
  CALL READ_AFF(filefirst,firstxyz)
  secondxyz = 'pikashu_merge2.xyz'
  CALL READ_AFF(filesecond,secondxyz)
  IF(nerr>0) GOTO 1000
  !
  !Merge the two XYZ files
  CALL MERGE_XYZ(firstxyz,secondxyz,outputfile)
  !
!
!
!
! === ADD OTHER MODES HERE ===
!
!
!
ENDIF
GOTO 1000
!
!
800 CONTINUE
!
!
!
1000 CONTINUE
!
!
END SUBROUTINE RUN_MODE
!
END MODULE modes
