MODULE out_cfg 
!
!**********************************************************************************
!*  OUT_CFG                                                                       *
!**********************************************************************************
!* This module writes Ju Li's extended CFG format.                                *
!* The CFG format is described here:                                              *
!*    http://mt.seas.upenn.edu/Archive/Graphics/A/#standard_CFG                   *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 18 April 2010                                    *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_CFG(outputfile)
!
CHARACTER(LEN=2):: spieces
CHARACTER(LEN=12):: test
CHARACTER(LEN=64):: outputfile
CHARACTER(LEN=128):: comment, msg
INTEGER:: i, NP, wrap
REAL*8:: smass
REAL*8:: x, y, z
REAL*8,DIMENSION(4):: P
REAL*8,DIMENSION(3,3):: G
!
!
!Initialize variables
 comment = 'File generated by pikashu'
G(:,:) = 0.d0
i=1
!
100 CONTINUE
msg = 'debug --> entering WRITE_CFG'
CALL DISPLAY_MSG(verbosity,msg,logfile)
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=250,POSITION='REWIND')
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=250)
!
!Read the number of particles and comment
READ(35,*) NP
READ(35,'(a128)') comment
 comment = TRIM(ADJUSTL(comment))
!
!Calculate the inverse of matrix H
msg = 'debug --> inverting matrix H'
CALL DISPLAY_MSG(verbosity,msg,logfile)
CALL INVMAT(H,G)
!
! Write header of CFG file
CONTINUE
msg = 'debug --> writing header of CFG file: '//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
WRITE(40,101) 'Number of particles = ', NP
WRITE(40,'(a45)') 'A = 1.000000000 Angstrom (basic length-scale)'
!WRITE(40,*) '# '//TRIM(comment)
WRITE(40,102) 'H0(1,1) = ', H(1,1)
WRITE(40,102) 'H0(1,2) = ', H(1,2)
WRITE(40,102) 'H0(1,3) = ', H(1,3)
WRITE(40,102) 'H0(2,1) = ', H(2,1)
WRITE(40,102) 'H0(2,2) = ', H(2,2)
WRITE(40,102) 'H0(2,3) = ', H(2,3)
WRITE(40,102) 'H0(3,1) = ', H(3,1)
WRITE(40,102) 'H0(3,2) = ', H(3,2)
WRITE(40,102) 'H0(3,3) = ', H(3,3)
WRITE(40,'(a13)') '.NO_VELOCITY.'
WRITE(40,'(a15)') 'entry_count = 3'
101 FORMAT(a22,i10)
102 FORMAT(a10,f16.6)
!
!
200 CONTINUE
! Write coordinates in CFG file
WRITE(msg,'(a32,i6)') 'debug --> write coordinates, NP=', NP
CALL DISPLAY_MSG(verbosity,msg,logfile)
P(:) = 0.d0
test = ''
smass = 0.d0
spieces = ''
!
DO i=1,NP
  ! Read atomic coordinates from XYZ file
  READ(35,*,ERR=250,END=250) smass, x, y, z
  !
  !If it is a new spieces we have to write it in the CFG file
  IF(smass.NE.P(4)) THEN
    P(4) = smass
    IF(P(4)==0.d0) GOTO 250
    !
    CALL ATOMSPIECES(smass,spieces)
    WRITE(40,'(f9.4)') P(4)
    WRITE(40,'(a2)') spieces
  ENDIF
  !
  ! Convert it to reduced coordinates
  P(1) = x*G(1,1) + y*G(2,1) + z*G(3,1)
  P(2) = x*G(1,2) + y*G(2,2) + z*G(3,2)
  P(3) = x*G(1,3) + y*G(2,3) + z*G(3,3)
  !
  ! Check if the coordinates of this atom are within the box
  DO WHILE(P(1)>1.d0 .OR. P(2)>1.d0 .OR. P(3)>1.d0 .OR.   &
    &      P(1)<0.d0 .OR. P(2)<0.d0 .OR. P(3)<0.d0)
      IF(P(1)>1.d0) P(1) = P(1)-1.d0
      IF(P(1)<0.d0) P(1) = P(1)+1.d0
      IF(P(2)>1.d0) P(2) = P(2)-1.d0
      IF(P(2)<0.d0) P(2) = P(2)+1.d0
      IF(P(3)>1.d0) P(3) = P(3)-1.d0
      IF(P(3)<0.d0) P(3) = P(3)+1.d0
      wrap = wrap+1
  ENDDO
  !
  ! Write atom coordinates in CFG file
  WRITE(40,'(3(f12.6,2X))') P(1), P(2), P(3)
END DO
GOTO 300
!
250 CONTINUE
msg = '/X\ ERROR: an error occured while reading the file pikashu.xyz'
CALL DISPLAY_MSG(3,msg,logfile)
WRITE(msg,*) 'debug --> this apparently occured while reading atom #', i
CALL DISPLAY_MSG(verbosity,msg,logfile)
nerr = nerr+1
GOTO 1000
!
!
300 CONTINUE
msg = "..> Successfully wrote CFG file: "//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
IF(wrap>0) THEN
  WRITE(msg,'(a8,i3,a19)') "       (", wrap, " particles wrapped)"
  CALL DISPLAY_MSG(verbosity,msg,logfile)
ENDIF
!
500 CONTINUE
!
1000 CONTINUE
CLOSE(35)
CLOSE(40)
!
END SUBROUTINE WRITE_CFG
!
!
END MODULE out_cfg
