MODULE out_dd
!
!**********************************************************************************
!*  OUT_DD                                                                        *
!**********************************************************************************
!* This module reads in two files in XYZ format, and                              *
!* writes a file in the ddplot (.dd) format.                                      *
!* This file format is described for instance on that page:                       *
!*     http://cnls.lanl.gov/~groger/codes/ddplot/ddplot.html                      *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 25 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
!
!
USE comv
USE constants
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_DD(xyz1,xyz2,outputfile)
!
CHARACTER(LEN=2):: spieces
CHARACTER(LEN=32):: test
CHARACTER(LEN=64):: xyz1, xyz2, outputfile
CHARACTER(LEN=128):: comment, msg
INTEGER:: i, k
INTEGER:: NP1, NP2
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
P(:) = 0.d0
 comment = 'File generated with pikashu'
!
!
msg = '>>> Building the ddplot file: '//TRIM(outputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
100 CONTINUE
OPEN(UNIT=31,FILE=xyz1,FORM='FORMATTED',STATUS='OLD')
OPEN(UNIT=32,FILE=xyz2,FORM='FORMATTED',STATUS='OLD')
OPEN(UNIT=40,FILE=outputfile,FORM='FORMATTED',STATUS='UNKNOWN')
!
!Read number of atoms in XYZ files
READ(31,*) NP1
READ(32,*) NP2
IF(NP1.NE.NP2) THEN
  msg = 'X!X ERROR: the two files do not have the same number of atoms!'
  CALL DISPLAY_MSG(3,msg,logfile)
  GOTO 200
ENDIF
!
!Display a message if number of atoms is too big for ddplot
IF(NP1>6000) THEN
  nwarn = nwarn+1
  WRITE(msg,*) '/!\ WARNING: number of particles if very large:', NP1
  CALL DISPLAY_MSG(3,msg,logfile)
  WRITE(msg,*) '    If ddplot cannot display so many atoms, then use'
  CALL DISPLAY_MSG(3,msg,logfile)
  WRITE(msg,*) '    pikashu with the -cut option to reduce the number of atoms.'
  CALL DISPLAY_MSG(3,msg,logfile)
ENDIF
!
!Read comment in second XYZ file
READ(31,*) test
READ(32,'(a128)') comment
!
!
!Write header of DD file
WRITE(40,'(a4)') 'CSYS'
WRITE(40,'(a5)') '1 0 0'
WRITE(40,'(a5)') '0 1 0'
WRITE(40,'(a5)') '0 0 1'
WRITE(40,'(a6)') 'PERIOD'
WRITE(40,'(3(f10.6,X))') H(1,1), H(2,2), H(3,3)
WRITE(40,'(a12)') 'DISLO_CENTER'
WRITE(40,*) '0.000 0.000'
WRITE(40,'(a9)') 'NUM_UNREL'
WRITE(40,'(i5)') NP1
WRITE(40,'(a10)') 'COOR_UNREL'
!
!Write positions of 1st XYZ file
k=1
DO i=1,NP1
  READ(31,*) spieces, P(1), P(2), P(3)
  CALL ATOMMASS(spieces,P(4))
  WRITE(40,110) P(1), P(2), P(3), P(4)
ENDDO
!
!Write second section of DD file
WRITE(40,'(a7)') 'NUM_REL'
WRITE(40,'(i5)') NP1
WRITE(40,'(a8)') 'COOR_REL'
!
!Write positions of 2nd XYZ file
k=1
DO i=1,NP1
  READ(32,*) test, P(1), P(2), P(3)
  WRITE(40,110) P(1), P(2), P(3)
ENDDO
110 FORMAT(3(f15.9,X),f7.2)
!
!
!
200 CONTINUE
CLOSE(31)
CLOSE(32)
CLOSE(40)
!
msg = '..> I wrote the file '//TRIM(outputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
1000 CONTINUE
!
!
END SUBROUTINE WRITE_DD
!
END MODULE out_dd
