MODULE out_gulp_gin
!
!
!**********************************************************************************
!*  OUT_GULP_GIN                                                                  *
!**********************************************************************************
!* This module writes a GULP input file (.gin) draft.                             *
!* Only atomic positions and cell parameters are written, so the rest of          *
!* the GIN file (atomic potential, simulation parameters, etc.) has to be         *
!* completed by the user.                                                         *
!* This format is described in the GULP manual, which can be found here:          *
!*    https://www.ivec.org/gulp/help/manuals.html                                 *
!**********************************************************************************
!* (C) March 2010 - Pierre Hirel                                                  *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 14 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_GIN(outputfile)
!
CHARACTER(LEN=2):: spieces
CHARACTER(LEN=64):: outputfile
CHARACTER(LEN=128):: msg, comment
INTEGER:: i, NP
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
P(:) = 0.d0
 comment = 'File generated by pikashu'
!
100 CONTINUE
msg = 'debug --> entering WRITE_GIN'
CALL DISPLAY_MSG(verbosity,msg,logfile)
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=500,POSITION='REWIND')
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=500)
!
!Read header of pikashu.xyz
READ(35,*) NP
READ(35,'(a128)') comment
!
!Write header of GIN file
WRITE(40,*) 'opti conv   #set the keywords here'
WRITE(40,*) ''
WRITE(40,'(a5)') 'title'
WRITE(40,*) TRIM(comment)
WRITE(40,'(a3)') 'end'
WRITE(40,*) ''
WRITE(40,*) '### insert simulation parameters here'
WRITE(40,*) ''
WRITE(40,'(a7)') 'vectors'
WRITE(40,110) '  ', H(1,1), H(1,2), H(1,3)
WRITE(40,110) '  ', H(2,1), H(2,2), H(2,3)
WRITE(40,110) '  ', H(3,1), H(3,2), H(3,3)
WRITE(40,*) ''
110 FORMAT(a2,3(f16.8))
!
!
!
200 CONTINUE
!Write atoms coordinates
WRITE(40,'(a10,i6)') 'cartesian ', NP
DO i=1,NP
  READ(35,*,END=500,ERR=500) P(4), P(1), P(2), P(3)
  CALL ATOMSPIECES(P(4),spieces)
  WRITE(40,210) spieces, ' core ', P(1), P(2), P(3)
ENDDO
210 FORMAT(a2,a6,3(f16.8,2X))
!
!
!
500 CONTINUE
CLOSE(35)
CLOSE(40)
msg = "..> Successfully wrote GIN file: "//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
1000 CONTINUE
!
END SUBROUTINE WRITE_GIN
!
END MODULE out_gulp_gin
