MODULE out_lammps_data
!
!
!**********************************************************************************
!*  OUT_LAMMPS_DATA                                                               *
!**********************************************************************************
!* This module writes a data file for LAMMPS, that can be called                  *
!* with the  'read_data <filename>' in the LAMMPS input file.                     *
!**********************************************************************************
!* (C) June 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 11 June 2010                                     *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_LMP_DATA(outputfile)
!
CHARACTER(LEN=2):: spieces, spitemp
CHARACTER(LEN=64):: outputfile
CHARACTER(LEN=128):: msg, comment
INTEGER:: atype, i, NP
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
P(:) = 0.d0
 comment = 'File generated by pikashu'
!
!
100 CONTINUE
msg = 'debug --> entering WRITE_LMP_DATA'
CALL DISPLAY_MSG(verbosity,msg,logfile)
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=500,POSITION='REWIND')
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=500)
!
!Read header of pikashu.xyz
READ(35,*) NP
READ(35,'(a128)') comment
!
!Write header of data file
WRITE(40,*) '#'//TRIM(comment)
WRITE(40,*) NP, '  atoms'
!
!Read and write atomic positions
WRITE(40,*) 'Atoms'
spitemp = ''
atype = 0
DO i=1,NP
  READ(35,*,END=500,ERR=500) P(4), P(1), P(2), P(3)
  CALL ATOMSPIECES(P(4),spieces)
  IF(spieces.NE.spitemp) atype = atype+1
  WRITE(40,110) i, atype, 'q'//spieces, P(1), P(2), P(3)
ENDDO
110 FORMAT(i6,X,i3,X,a3,2x,3(f16.8,2X))
!
!
!
500 CONTINUE
CLOSE(35)
CLOSE(40)
msg = "..> Successfully wrote LAMMPS data file: "//TRIM(outputfile)
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
1000 CONTINUE
!
END SUBROUTINE WRITE_LMP_DATA
!
END MODULE out_lammps_data
