MODULE out_vasp_poscar
!
!
!**********************************************************************************
!*  OUT_VASP_POSCAR                                                               *
!**********************************************************************************
!* This module writes POSCAR files, as well as CONTCAR files since it             *
!* is the same format. These files are used by VASP.                              *
!* The POSCAR format is described here:                                           *
!*    http://cms.mpi.univie.ac.at/vasp/vasp/node61.html                           *
!* Beware that atomic spieces are not specified in the POSCAR format,             *
!* hence that information is lost when converting from any format to POSCAR.      *
!**********************************************************************************
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 05 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_POSCAR(outputfile)
!
CHARACTER(LEN=12):: test
CHARACTER(LEN=64):: outputfile, comment
CHARACTER(LEN=128):: msg
INTEGER:: i, j, NP, NS
INTEGER,DIMENSION(20):: NPi
REAL*8:: smass
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
 comment = 'File generated by pikashu'
NP = 0
NS = 0        !Number of dinstinct atomic spieces
NPi(:) = 0.d0 !Number of atoms for each spieces
P(:) = 0.d0
!
100 CONTINUE
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=500)
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=500)
!
!Read header of pikashu.xyz
READ(35,*,END=400,ERR=400) NP
READ(35,'(a64)',END=400,ERR=400) comment
!
!Write header of POSCAR file
WRITE(40,*) TRIM(ADJUSTL(comment))
WRITE(40,'(a8)') '1.000000'
WRITE(40,101) H(1,1), H(1,2), H(1,3)
WRITE(40,101) H(2,1), H(2,2), H(2,3)
WRITE(40,101) H(3,1), H(3,2), H(3,3)
101 FORMAT(3(f12.6,2X))
!
!Count the number of atoms for each atomic spieces
smass = -1.d0
j = 0
DO i=1,NP
  READ(35,*,END=400,ERR=400) P(4)
  IF(P(4).NE.smass) THEN
    smass = P(4)
    NS = NS+1
    j = j+1
  ENDIF
  NPi(j) = NPi(j)+1
ENDDO
!
WRITE(msg,*) "debug --> Number of different spieces: ", NS
CALL DISPLAY_MSG(verbosity,msg,logfile)
WRITE(40,'(20i4)') (NPi(j), j=1,NS)
!
REWIND(35)
READ(35,*) test  !NP
READ(35,*) test  !comment
WRITE(40,'(a9)') 'Cartesian'
DO i=1,NP
  READ(35,*,END=400,ERR=400) P(4), P(1), P(2), P(3)
  WRITE(40,110) P(1), P(2), P(3)
ENDDO
110 FORMAT(3(f16.8,2X))
GOTO 500
!
!
!
400 CONTINUE
msg = "X!X ERROR: there was a problem while reading pikashu.xyz"
CALL DISPLAY_MSG(verbosity,msg,logfile)
msg = "    Program will EXIT."
CALL DISPLAY_MSG(verbosity,msg,logfile)
nerr = nerr+1
!
!
!
500 CONTINUE
CLOSE(35)
CLOSE(40)
msg = "..> Successfully wrote POSCAR file: "//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
1000 CONTINUE
!
END SUBROUTINE WRITE_POSCAR
!
END MODULE out_vasp_poscar
