MODULE out_xsf
!
!
!**********************************************************************************
!*  OUT_XSF                                                                       *
!**********************************************************************************
!* This module writes XSF format, initially designed for XCrysDen.                *
!* The XSF format is described here:                                              *
!*    http://www.xcrysden.org/doc/XSF.html                                        *
!**********************************************************************************
!* Version of this module: 0.1                                                    *
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 12 fev. 2010                                     *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_XSF(outputfile)
!
CHARACTER(LEN=12):: test
CHARACTER(LEN=64):: outputfile
CHARACTER(LEN=128):: msg, comment
INTEGER:: i, NP
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
P(:) = 0.d0
 comment = 'File generated by pikashu'
!
100 CONTINUE
msg = 'debug --> entering WRITE_XSF'
CALL DISPLAY_MSG(verbosity,msg,logfile)
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=500,POSITION='REWIND')
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=500)
!
!Read header of pikashu.xyz
READ(35,*) NP
READ(35,*) test
!
!Write header of XSF file
WRITE(40,*) "CRYSTAL"
WRITE(40,*) "PRIMVEC"
WRITE(40,105) H(1,1), H(1,2), H(1,3)
WRITE(40,105) H(2,1), H(2,2), H(2,3)
WRITE(40,105) H(3,1), H(3,2), H(3,3)
WRITE(40,*) "CONVVEC"
WRITE(40,105) H(1,1), H(1,2), H(1,3)
WRITE(40,105) H(2,1), H(2,2), H(2,3)
WRITE(40,105) H(3,1), H(3,2), H(3,3)
WRITE(40,*) "PRIMCOORD"
WRITE(40,'(i9,a2)') NP, ' 1'
105 FORMAT(3(f16.8,2X))
!
DO i=1,NP
  READ(35,*,END=500,ERR=500) P(4), P(1), P(2), P(3)
  WRITE(40,110) INT(P(4)), P(1), P(2), P(3)
ENDDO
110 FORMAT(i5,2X,3(f16.8,2X))
!
500 CONTINUE
CLOSE(35)
CLOSE(40)
msg = "..> Successfully wrote XSF file: "//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
1000 CONTINUE
!
END SUBROUTINE WRITE_XSF
!
END MODULE out_xsf
