MODULE out_xyz
!
!
!**********************************************************************************
!*  OUT_XYZ                                                                       *
!**********************************************************************************
!* This module writes XYZ extended format, i.e.:                                  *
!*          NP                                                                    *
!*          #comment line                                                         *
!*          spieces1 x1 y1 z1                                                     *
!*          spieces2 x2 y2 z2                                                     *
!*          spieces3 x3 y3 z3                                                     *
!*           ...                                                                  *
!*          alat                                                                  *
!*          <a0>                                                                  *
!*          supercell                                                             *
!*          <H(1,1)> <H(1,2)> <H(1,3)>                                            *
!*          <H(2,1)> <H(2,2)> <H(2,3)>                                            *
!*          <H(3,1)> <H(3,2)> <H(3,3)>                                            *
!**********************************************************************************
!* Version of this module: 0.1                                                    *
!* (C) Feb. 2010 - Pierre Hirel                                                   *
!*     IZBS, Karlsruher Institut fuer Technologie                                 *
!*     Kaiserstr. 12, 76131 Karlsruhe, Germany                                    *
!*     pierre.hirel@izbs.uni-karlsruhe.de                                         *
!* Last modification: P. Hirel - 14 May 2010                                      *
!**********************************************************************************
!* This is free software, distributed under GNU/GPL version3 or greater, see:     *
!*   http://www.gnu.org/licenses/gpl.html                                         *
!* or look at the LICENSE file provided with this program.                        *
!**********************************************************************************
!
USE comv
USE constants
USE functions
USE messages
USE files
USE subroutines
!
IMPLICIT NONE
!
!
CONTAINS
!
SUBROUTINE WRITE_XYZ(outputfile)
!
CHARACTER(LEN=2):: spieces
CHARACTER(LEN=64):: outputfile
CHARACTER(LEN=128):: msg, comment
INTEGER:: i, NP
REAL*8,DIMENSION(4):: P
!
!
!Initialize variables
P(:) = 0.d0
 comment = 'File generated by pikashu'
!
!
100 CONTINUE
msg = 'debug --> entering WRITE_XYZ'
CALL DISPLAY_MSG(verbosity,msg,logfile)
OPEN(UNIT=35,FILE='pikashu.xyz',STATUS='OLD',ERR=500,POSITION='REWIND')
OPEN(UNIT=40,FILE=outputfile,STATUS='UNKNOWN',ERR=500)
!
!Read header of pikashu.xyz
READ(35,*) NP
READ(35,'(a128)') comment
!
!Write header of XYZ file
WRITE(40,*) NP
WRITE(40,*) TRIM(comment)
!
!Read and write atomic positions
DO i=1,NP
  READ(35,*,END=500,ERR=500) P(4), P(1), P(2), P(3)
  CALL ATOMSPIECES(P(4),spieces)
  WRITE(40,110) spieces, P(1), P(2), P(3)
ENDDO
110 FORMAT(a2,2X,3(f16.8,2X))
!
!Write footer of XYZ file
WRITE(40,'(a4)') 'alat'
WRITE(40,'(a3)') '1.0'
WRITE(40,'(a9)') 'supercell'
WRITE(40,'(3(f12.6,X))') H(1,1), H(1,2), H(1,3)
WRITE(40,'(3(f12.6,X))') H(2,1), H(2,2), H(2,3)
WRITE(40,'(3(f12.6,X))') H(3,1), H(3,2), H(3,3)
!
!
!
500 CONTINUE
CLOSE(35)
CLOSE(40)
msg = "..> Successfully wrote XYZ file: "//outputfile
CALL DISPLAY_MSG(verbosity,msg,logfile)
!
!
!
1000 CONTINUE
!
END SUBROUTINE WRITE_XYZ
!
END MODULE out_xyz
